==> Paws-0.02.tar.gz: Paws-0.02/lib/Paws/IAM/GetPolicy.pm <==

package Paws::IAM::GetPolicy {
  use Moose;
  has PolicyArn => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetPolicy');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetPolicyResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetPolicyResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetPolicy - Arguments for method GetPolicy on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetPolicy on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method GetPolicy.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetPolicy.

As an example:

  $service_obj->GetPolicy(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> PolicyArn => Str

  



=head1 SEE ALSO

This class forms part of L<Paws>, and documents parameters for GetPolicy in Paws::IAM

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.13.tar.gz: Paws-0.13/lib/Paws/IAM/GetPolicy.pm <==

package Paws::IAM::GetPolicy {
  use Moose;
  has PolicyArn => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetPolicy');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IAM::GetPolicyResponse');
  class_has _result_key => (isa => 'Str', is => 'ro', default => 'GetPolicyResult');
}
1;

### main pod documentation begin ###

=head1 NAME

Paws::IAM::GetPolicy - Arguments for method GetPolicy on Paws::IAM

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetPolicy on the 
AWS Identity and Access Management service. Use the attributes of this class
as arguments to method GetPolicy.

You shouln't make instances of this class. Each attribute should be used as a named argument in the call to GetPolicy.

As an example:

  $service_obj->GetPolicy(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES

=head2 B<REQUIRED> PolicyArn => Str

  



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetPolicy in L<Paws::IAM>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
